czekitout
=========

``czekitout`` is a Python library that contains a collection of functions that
facilitate type-checking, validation, and type-conversions, with useful error
messages when exceptions are thrown.

Setting up czekitout
--------------------

For instructions on installing the ``czekitout`` library, see the
:ref:`installation_instructions_sec` page.

Learning how to use czekitout
-----------------------------

For those new to the ``czekitout`` library, it is recommended that they take a
look at the :ref:`examples_sec` page, which contains some code examples that
show how one can use the ``czekitout`` library. While going through the
examples, readers can consult the :ref:`reference_guide_sec` to understand what
each line of code is doing in each example.
	     
Contents
--------
.. toctree::
   :maxdepth: 6
   :numbered:

   home <self>
   INSTALL
   Reference <_autosummary/czekitout>
   examples
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
